from datetime import datetime as dt

def time_now(int_times: bool = False):
    """Returns the current time in string format HH-MM."""
    if not int_times:
        return dt.now().strftime("%H-%M")
    else:
        time_hours, time_mins = dt.now().strftime("%H-%M").split(sep = '-')
        return (int(time_hours), int(time_mins))

def time_decimal():
    """Returns the time as a float. 08-30 is 8.5."""
    time_hours, time_mins = time_now(int_times = True)
    fraction_mins = time_mins/60
    fractional_time = time_hours + fraction_mins
    return float(fractional_time)

def time_seconds(int_output: bool = False):
    if int_output:
        return int(dt.now().strftime("%S"))
    else:
        return dt.now().strftime("%S")

def today_date():
    """Returns today's date in string format 2022-02-22."""
    return str(dt.now().date())

def weekday_int():
    """Returns the integer 1-7 of weekday where 1 is Monday."""
    iso_weekday = dt.now().isoweekday()
    return int(iso_weekday)

def weekly_time_decimal():
    """
    Returns decimal time within a week. For example, Tuesday noon is 1.5.
    Values start at 0, midnight on Monday.
    """

    daily_fraction = time_decimal()/24
    today_weekday = weekday_int() - 1
    return float(today_weekday + daily_fraction)


class Document:
    """Document object with directory and contents attributes."""
    def __init__(self, directory: str):
        self.directory = directory
        
        ## Checks
        if ".txt" not in self.directory:
            raise Exception("You must compare two text files.")

        ## Contents
        with open(self.directory, 'r') as f:
            self.contents = f.read()

def are_docs_same(original_dir: str, new_dir: str):
    """Checks if the contents of two files are exactly identical. Returns boolean."""
    # Get contents
    Original = Document(directory = original_dir)
    New = Document(directory = new_dir)

    # Check contents
    if Original.contents == New.contents:
        print("Contents match.")
        return True
    else:
        print("Contents do not match.")
        return False

def append_by_query(query: str, content: str, file_path: str, insert_above: bool = False):
    """
    Required args: query, content, and file path. 
    Optional args: insert_above

    Searches through the contents of the target file and inserts content a line below \
        the first occurence. 
    """
    
    # Open the file and get the lines
    with open(file_path, 'r') as f:
        data = f.readlines()

    # Check for the <title>
    found_the_line = False # exception handling
    for pos, line in enumerate(data):
        if query in line:
            found_the_line = True
            break
    
    # Quit the program if <title> wasn't found
    if not found_the_line:
        raise Exception(f"{query} not found in any lines of {file_path}.") 

    # Insert after? Increase line number by 1.
    if not insert_above:
        pos += 1

    # Append the string
    data.insert(pos, (content + '\n'))
    with open(file_path, 'w') as f:
        f.writelines(data)


# Files
from mypytoolkit.files import *

# Date and time
from mypytoolkit.dates import *

# Linear equation plotting
from mypytoolkit.math import LinearEquation

# General Python tools
from mypytoolkit.pyfuncs import *


from matplotlib import pyplot as plt
import numpy as np

class LinearEquation:
    def __init__(self, slope: float, intercept: float):
        self.slope = slope
        self.intercept = intercept

    def plot(self, interval: int, step = 1):
        fig, ax = plt.subplots()
        x = np.arange(1, interval, step)
        y = (self.slope * x) + self.intercept
        ax.plot(x, y)
        plt.show()


from setuptools import setup, find_packages

VERSION = "1.3.4"
DESCRIPTION = (
    "Basic tools I feel are missing in the standard Python distribution."
)

def get_read_me():
    with open("README.md", "r") as f:
        return f.read()

# Setting up
setup(
    name="mypytoolkit",
    version=VERSION,
    author="Prerit Das",
    author_email="<preritdas@gmail.com>",
    description=DESCRIPTION,
    long_description=get_read_me(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires = ["DateTime", "matplotlib", "numpy"],
    keywords=["python", "tools"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
)



def tprint(arg):
    """Prints the contents of a variable/object along with its type."""
    print(arg, type(arg))

def count(iterable, value):
    """Returns an integer of the number of occurences of a value in an iterable."""
    count = 0
    for item in iterable:
        if item == value:
            count += 1
    return int(count)

def reverse_dict(dic: dict):
    """Reverses the keys and values in a dictionary."""
    new_dict = {}
    for key, val in dic.items():
        new_dict[val] = key
    return new_dict